/*
	FILENAME
		ChooserLDEF.r

	DESCRIPTION
		Contains resources needed in order for this driver to work with
		the Chooser.

	COPYRIGHT
		Copyright  1995 Apple Computer, Inc.
		All rights reserved.
	
	Modification history
		10/04/95 - David Hayward -	Version 1.0.4 modified code so that
									the driver can be build under MPW,
									Metrowerks, and Symantec.  In general,
									all that was required to do this was 
									to add an inline-assembly jumptable
									and to store all globals off of the
									message manager instance context.
									Also made a few changes so that the
									driver can be rebuilt to support any
									resolution by changing the #defines
									kResolution and kPatStretch in
									"CommonDefines.h"

		06/14/95 - Dave Hersey -	Version 1.0.3 to fix a bug in
									CustomBufferingAndIO.c when creating
									high-res PICTs, and to make the size
									of buffers more flexible.

		05/26/95 - Dave Hersey -	Version 1.0.2 to add the new 'outp'
									desktop printer resource in NewApp.c.

		05/03/95 - Dave Hersey -	Version 1.0.1 to fix some minor bugs in
									CustomBufferingAndIO.c.

		01/14/95 - Dave Hersey -	Created from the shell of a hollowed-out
									ImageWriter driver.
*/


#include "Types.r"
#include "SysTypes.r"
#include "GXPrintingResTypes.r"
#include "GXPrintingResEquates.r"
#include "ChooserLDEF.h"


//--------------------------------------------------------------------------------------------
// ICON TO DISPLAY IN THE CHOOSER'S DEVICE LIST
//--------------------------------------------------------------------------------------------

data 'cicn' (r_ChooserIcon, sysheap, purgeable) {
	$"0000 0000 8010 0000 0000 0020 0020 0000 0000 0000 0000 0048 0000"                 /* .......... . .........H.. */
	$"0048 0000 0000 0004 0001 0004 0000 0000 0000 0000 0000 0000 0000"                 /* .H........................ */
	$"0000 0004 0000 0000 0020 0020 0000 0000 0004 0000 0000 0020 0020"                 /* ......... . ........... .  */
	$"0000 0000 1FFF FC00 1FFF FE00 1FFF FF00 1FFF FF80 1FFF FFC0 1FFF"                 /* ............. */
	$"FFE0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"                 /* ...... */
	$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF"                 /* ....... */
	$"FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"                 /* ...... */
	$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF"                 /* ....... */
	$"FFF0 1FFF FC00 1000 0600 1000 0500 1000 0480 1000 0440 1000 0420"                 /* ................@...  */
	$"1000 07F0 1000 0010 1000 0010 1000 0010 11FE 0010 1102 1C10 1102"                 /* ........................ */
	$"2210 1102 4110 11FE 4110 1000 4110 1002 2210 1005 1C10 1008 8010"                 /* "...A..A...A..."........ */
	$"1010 4010 1020 2010 1010 4010 1008 8010 1005 0010 1002 0010 1000"                 /* ..@..  ...@.............. */
	$"0010 1000 0010 1000 0010 1000 0010 1000 0010 1000 0010 1FFF FFF0"                 /* ....................... */
	$"0000 0000 0000 0006 0000 FFFF FFFF FFFF 0001 9999 FFFF FFFF 0002"                 /* .............. */
	$"6666 6666 CCCC 0003 FFFF 6666 CCCC 0004 EEEE EEEE EEEE 0005 CCCC"                 /* ffff..ff.... */
	$"CCCC CCCC 000F 0000 0000 0000 000F FFFF FFFF FFFF FFFF FF00 0000"                 /* ............. */
	$"0000 000F 4444 4444 4444 4444 4FF0 0000 0000 000F 4444 4444 4444"                 /* ....DDDDDDDDO......DDDDDD */
	$"4444 4F5F 0000 0000 000F 4444 4444 4444 4444 4F55 F000 0000 000F"                 /* DDO_......DDDDDDDDOU..... */
	$"4444 4444 4444 4444 4F55 5F00 0000 000F 4444 4444 4444 4444 4F55"                 /* DDDDDDDDOU_.....DDDDDDDDOU */
	$"55F0 0000 000F 4444 4444 4444 4444 4FFF FFFF 0000 000F 4444 4444"                 /* U....DDDDDDDDO....DDDD */
	$"4444 4444 4444 444F 0000 000F 4444 4444 4444 4444 4444 444F 0000"                 /* DDDDDDDO....DDDDDDDDDDDO.. */
	$"000F 4444 4444 4444 4444 4444 444F 0000 000F 444F FFFF FFF4 4444"                 /* ..DDDDDDDDDDDO....DODD */
	$"4444 444F 0000 000F 444F 1111 11F4 444F FF44 444F 0000 000F 444F"                 /* DDDO....DO...DODDO....DO */
	$"1111 11F4 44F3 33F4 444F 0000 000F 444F 1111 11F4 4F33 333F 444F"                 /* ...D3DO....DO...O33?DO */
	$"0000 000F 444F FFFF FFF4 4F33 333F 444F 0000 000F 4444 4444 4444"                 /* ....DOO33?DO....DDDDDD */
	$"4F33 333F 444F 0000 000F 4444 4444 44F4 44F3 33F4 444F 0000 000F"                 /* O33?DO....DDDDDD3DO.... */
	$"4444 4444 4F2F 444F FF44 444F 0000 000F 4444 4444 F222 F444 4444"                 /* DDDDO/DODDO....DDDD"DDD */
	$"444F 0000 000F 4444 444F 2222 2F44 4444 444F 0000 000F 4444 44F2"                 /* DO....DDDO""/DDDDO....DDD */
	$"2222 22F4 4444 444F 0000 000F 4444 444F 2222 2F44 4444 444F 0000"                 /* """DDDO....DDDO""/DDDDO.. */
	$"000F 4444 4444 F222 F444 4444 444F 0000 000F 4444 4444 4F2F 4444"                 /* ..DDDD"DDDDO....DDDDO/DD */
	$"4444 444F 0000 000F 4444 4444 44F4 4444 4444 444F 0000 000F 4444"                 /* DDDO....DDDDDDDDDDO....DD */
	$"4444 4444 4444 4444 444F 0000 000F 4444 4444 4444 4444 4444 444F"                 /* DDDDDDDDDO....DDDDDDDDDDDO */
	$"0000 000F 4444 4444 4444 4444 4444 444F 0000 000F 4444 4444 4444"                 /* ....DDDDDDDDDDDO....DDDDDD */
	$"4444 4444 444F 0000 000F 4444 4444 4444 4444 4444 444F 0000 000F"                 /* DDDDDO....DDDDDDDDDDDO.... */
	$"4444 4444 4444 4444 4444 444F 0000 000F FFFF FFFF FFFF FFFF FFFF"                 /* DDDDDDDDDDDO.... */
	$"FFFF 0000"                                                                        /* .. */
};
