/*------------------------------------------------------------------------------
FILENAME
	Generic LaserWriter.r

DESCRIPTION
	This module contains all of the #defines which for the generic
	LaserWriter driver.
	
	6/14/96 - cn  - Updated to support Universal Interfaces 2.1.
	8/28/94 - dmh - Finalized for SDK.
	6/14/94 - dmh - Added the mystical, magical, 30 second alert.
	5/03/94 - dmh - Updated for the f2 seed.
	3/22/94 - dmh - Updated for the b4 seed.
   12/18/93	- dmh - Made non-IIg-specific for the b3 seed.
	9/13/93 - dmh - Updated for the b2 seed.
	4/26/93 - dmh - Updated for the b1 seed.

COPYRIGHT
	 Copyright Apple Computer, Inc. 1989-1996
	 All rights reserved. 
-------------------------------------------------------------------------------- */

#include "Types.r"
#include "SysTypes.r"
#include "GXPrintingResTypes.r"

// the defines

#define vShortVersionStr		"1.0"
#define	kDriverName				"Generic LaserWriter"
#define	kCreatorType			'scL2'
#define	kFileType				'pdvr'


#define kMyStatID				gxPrintingDriverBaseID
#define k30SecondDlogID			gxPrintingDriverBaseID

resource gxStatusType (gxPrintingDriverBaseID, sysheap, purgeable)
{
	kCreatorType,
	{
		userAlert, 100, k30SecondDlogID, "30 Second delay in progress.";
		printerReady, 200, 0, "Sending data to printer."
	}
};

resource gxPrintingAlertType (k30SecondDlogID, sysheap, purgeable)
{
	printingStatus,												// version
	stopIcon,													// icon id
	defaultSystemSize,
	defaultAction,												// default action label
	noCancelTitle,												// no cancel
	"For no good reason, your print job is "					// alert text
	"being delayed for 30 seconds.",
	"Resume",													// action label
	"",															// button label 2
	"",															// button label 3
	" ",														// font name 
	"Please wait 30 seconds"
};


/* ------------------------------------------------------------------------ */
/* 'vers' RESOURCE REQUIRED BY ALL PRINTER DRIVERS							*/
/* ------------------------------------------------------------------------ */

/*	The first byte of this resource must be zero or one for
	this driver to be compatible with GX v1.0.  The
	remainder of the data is ignored						*/

resource 'vers' (gxPrintingDriverBaseID, sysheap, purgeable) {
	0x0,
	0x0,
	release,
	0x0,
	verUS,
	"",
	""
};


// Normal 'vers' resources so we can tell what version we've got.

resource 'vers' (1, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	vShortVersionStr,
	vShortVersionStr",  Apple Computer, Inc. 1988-1994"
};


resource 'vers' (2, sysheap, purgeable) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	vShortVersionStr,
	"Sample Printer Driver"
};


/*------------------------------------------- the bundle ------------------------------------*/

type kCreatorType as 'STR ';

resource kCreatorType (0, sysheap, purgeable) { "Generic LaserWriter Driver " vShortVersionStr };

resource 'BNDL' (gxPrintingDriverBaseID + 1, sysheap, purgeable) {
	kCreatorType,
	0,
	{
		'FREF',
		{
			0, gxPrintingDriverBaseID,
			1, gxPrintingDriverBaseID + 1,
			2, gxPrintingDriverBaseID + 2,
			3, gxPrintingDriverBaseID + 3,
			4, gxPrintingDriverBaseID + 4,
			5, gxPrintingDriverBaseID + 5,
			6, gxPrintingDriverBaseID + 6,
			7, gxPrintingDriverBaseID + 7
		},
		'ICN#',
		{
			0, gxPrintingDriverBaseID + 2,
			1, gxPrintingDriverBaseID + 2,
			2, gxPrintingDriverBaseID + 3,
			3, gxPrintingDriverBaseID + 4,
			4, gxPrintingDriverBaseID + 5,
			5, gxPrintingDriverBaseID + 6,
			6, gxPrintingDriverBaseID + 6,
			7, gxPrintingDriverBaseID + 7
		}
	}
};

resource 'FREF' (gxPrintingDriverBaseID, sysheap, purgeable) {
	'pdvr',
	0,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 1, sysheap, purgeable) {
	'dpnn',
	1,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 2, sysheap, purgeable) {
	'dpns',
	2,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 3, sysheap, purgeable) {
	'dpcn',
	3,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 4, sysheap, purgeable) {
	'dpcs',
	4,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 5, sysheap, purgeable) {
	'dvcf',
	5,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	'dpna',
	6,
	""
};

resource 'FREF' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	'dppz',
	7,
	""
};

resource 'STR ' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) { vShortVersionStr };

resource gxDriverFileFormatType (gxDriverFileFormatID, sysheap, purgeable ) {

	{
		"PostScript"
	};
};

/* ------------------------- resources for scanning the status ----------------------*/

resource gxPostscriptScanningType ( gxPostscriptScanningID, sysheap, purgeable )
{
	0,
	{
	SimpleScan {"busy"}, SimpleScan { "printer busy" }, SimpleOffset {}, NoAction {};
	SimpleScan {"waiting"}, SimpleScan {"preparing data"}, SimpleOffset {}, NoAction {};	
	SimpleScan {"job:"}, SimpleScan {"User"}, SimpleOffset {}, NoAction {};
	}
};

resource gxPostscriptScanningType ( gxPostscriptScanningID + 1, sysheap, purgeable )
{
	0,
	{
	SimpleScan {"%%["}, SimpleScan {""}, SimpleOffset {}, NoAction {};
	SimpleScan {"]%%"}, SimpleScan {""}, SimpleOffset {}, NoAction {};
	SimpleScan {"PrinterError"}, SimpleScan {"Printer"}, SimpleOffset {}, NoAction {};
	}
};

/*-------------------------- resource for telling printing who we are ------------------------*/

// select which imaging system to use, the ID of the override resource, 
// and the number of overrides we use

resource gxImagingSystemSelectorType (gxImagingSystemSelectorID, sysheap, purgeable )
{
	gxPostscriptPrinterType	// we use the PostScript system
};


// this resource allows us to customize the old API's behavior

resource 'cust' (-8192, sysheap, purgeable )
{
	300, 300,					// our DPI
	laserWriter,				// we use the default up driver (LaserWriter)
	{4, 4},						// pattern stretch of 4 (nearest thing to 300 dpi/72 dpi)
	gxPostScriptTargetTranslation + gxOptimizedTranslation
};

// this resource tells the quickdraw driver about the resolution of the device

resource gxReslType ( gxReslID, sysheap, purgeable )
{
	rangeType,
	25, 1500,
	25,	1500,
	{ 300, 300 };
};

// this resource customizes the behavior of the universal driver, allowing us
// to use standard mechanisms for buffering and IO

resource gxUniversalIOPrefsType ( gxUniversalIOPrefsID, sysheap, purgeable  )
{
	standardIO,
	4,			// four buffers (univ driver WILL run with less if it needs to)
	1024*2,		// we want them to each be large enough for one scan line of data (at least)
	10,			// number of requests blocks to allocate for HIO
	600,		// wait 10 seconds to open and close connections
	1200,		// and 20 seconds for reading and writing
};

resource gxPostscriptPrefsType ( gxPostscriptPrefsID, sysheap, purgeable  )	
{
	1,											// language level
	gxRGBSpace,									// shape color space
	0,											// flags
	1500,										// path limit
	31,											// gsave limit
	500,										// operand stack limit
	type1StreamType + type3StreamType,			// the font type that this printer supports
	434204										// vm
};

/*----------------------------------------- message overrides --------------------------------*/

// overrides for universal messages and where to find them in the jump table

#define firstOffset		4
#define	segmentID		0

resource gxOverrideType ( gxDriverImagingOverrideID, sysheap, purgeable  )
	{
		{
			gxPostscriptDoPageSetUp, segmentID, firstOffset,
		};
	};

resource gxOverrideType ( gxDriverUniversalOverrideID, sysheap, purgeable  )
	{
		{
			gxOpenConnection,  	segmentID, firstOffset + 4,
			gxCloseConnection, 	segmentID, firstOffset + 8,
			gxInitialize,  		segmentID, firstOffset + 12,
			gxShutDown,  		segmentID, firstOffset + 16,
			gxDumpBuffer, 	 	segmentID, firstOffset + 20,
		};
	};

/*-------------------------------------------- LaserWriter paper types --------------------*/

resource 'ptyp'	( gxPrintingDriverBaseID + 1, sysheap, purgeable  )	{
	
	"US Letter",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x0247AE18,				/* 8.10667 */
	0x0308A3DC,				/* 10.7867 */

		/* paper rectangle */
	0xFFF1D70C,				/* -0.196666 */
	0xFFF870A8,				/* -0.104999 */
	0x0255D70C,				/* 8.30333 */
	0x031070A8,				/* 10.895 */
	
	usLetterBase,
	kCreatorType,

	inch,

	oldAndNewStylePaperType,
	isDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/letter dup where { pop load exec }{ pop } ifelse\n"
	}
};

resource 'ptyp' ( gxPrintingDriverBaseID + 2, sysheap, purgeable  )	{
	
	"US Legal",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x0247AE18,				/* 8.10667 */
	0x03E0A3DC,				/* 13.7867 */

		/* paper rectangle */
	0xFFF1D70C,				/* -0.196666 */
	0xFFF870A8,				/* -0.104999 */
	0x0255D70C,				/* 8.30333 */
	0x03E870A8,				/* 13.895 */

	usLegalBase,
	kCreatorType,

	inch,
	
	oldAndNewStylePaperType,
	notDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/legal dup where { pop load exec }{ pop } ifelse\n"
	}
};


resource 'ptyp' ( gxPrintingDriverBaseID + 3, sysheap, purgeable  )	{

	"A4 Letter",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x023851EC,				/* 7.89333 */
	0x0337AE18,				/* 11.44 */

		/* paper rectangle */
	0xFFF3A3C0,				/* -0.18 */
	0xFFF73D74,				/* -0.121666 */
	0x02467AE4,				/* 8.09 */
	0x0340EB88,				/* 11.5683 */

	a4LetterBase,
	kCreatorType,

	inch,
	
	oldAndNewStylePaperType,
	notDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/a4 dup where { pop load exec }{ pop } ifelse\n"
	}
};

resource 'ptyp' ( gxPrintingDriverBaseID + 4, sysheap, purgeable  )	{

	"B5 Letter",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x01E3D70C,				/* 6.72 */
	0x02C28F60,				/* 9.81333 */

		/* paper rectangle */
	0xFFEB5C2A,				/* -0.286666 */
	0x000751EC,				/* 0.101667 */
	0x01DE51EC,				/* 6.64333 */
	0x02CBCCD0,				/* 9.94167 */

	b5LetterBase,
	kCreatorType,

	inch,
	
	oldAndNewStylePaperType,
	notDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/b5 dup where { pop load exec }{ pop } ifelse\n"
	}	
};

resource 'ptyp' ( gxPrintingDriverBaseID + 5, sysheap, purgeable  )	{

	"US Letter (small)",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x023851F0,				/* 7.89333 */
	0x02E5999C,				/* 10.3 */

		/* paper rectangle */
	0xFFEA28F6,				/* -0.303333 */
	0xFFE6B854,				/* -0.351111 */
	0x024E28F8,				/* 8.19667 */
	0x02FEB854,				/* 10.6489 */

	usLetterBase,
	kCreatorType,

	inch,
	
	oldAndNewStylePaperType,
	notDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/lettersmall dup where { pop load exec }{ pop } ifelse\n"
	}	
};

resource 'ptyp' ( gxPrintingDriverBaseID + 6, sysheap, purgeable  )	{

	"A4 Letter (small)",
	
		/* page rectangle */
	0x00000000,				/* 0.0 */
	0x00000000,				/* 0.0 */
	0x0228F5C4,				/* 7.68 */
	0x0317C294,				/* 10.9967 */

		/* paper rectangle */
	0xFFEB5C28,				/* -0.286667 */
	0xFFE7147C,				/* -0.346111 */
	0x023ECCD0,				/* 7.98333 */
	0x0330C290,				/* 11.3439 */

	a4LetterBase,
	kCreatorType,

	inch,
	
	oldAndNewStylePaperType,
	notDefaultPaperType,
	{
		'post',
		gxPrintingTagID,
		itemLocked,
		itemPersistent,
		0,
		"/a4small dup where { pop load exec }{ pop } ifelse\n"
	}	
};


/*-------------------------- resources for printer fonts ---------------------------------*/

resource 'pfnt' ( 128, "AvantGarde-Book", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 129, "AvantGarde-BookOblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 130, "AvantGarde-Demi", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 131, "AvantGarde-DemiOblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 132, "Bookman-Demi", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 133, "Bookman-DemiItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 134, "Bookman-Light", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 135, "Bookman-LightItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 136, "Courier", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 137, "Courier-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 138, "Courier-BoldOblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 139, "Courier-Oblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 140, "Helvetica", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 141, "Helvetica-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 142, "Helvetica-BoldOblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 143, "Helvetica-Narrow", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 144, "Helvetica-Narrow-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 145, "Helvetica-Narrow-BoldOblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 146, "Helvetica-Narrow-Oblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 147, "Helvetica-Oblique", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 148, "NewCenturySchlbk-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 149, "NewCenturySchlbk-BoldItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 150, "NewCenturySchlbk-Italic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 151, "NewCenturySchlbk-Roman", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 153, "Palatino-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 154, "Palatino-BoldItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 155, "Palatino-Italic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 156, "Palatino-Roman", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 157, "Symbol", sysheap, purgeable )		{
	ROMFont,
	AppleCharacterSet {
		191,
		$"9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF"
	};	
};
resource 'pfnt' ( 158, "Times-Bold", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 159, "Times-BoldItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 160, "Times-Italic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 161, "Times-Roman", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};
resource 'pfnt' ( 162, "ZapfChancery-MediumItalic", sysheap, purgeable )		{
	ROMFont,
	AdobeCharacterSet {};
};

/* -------------------------------- the icons ---------------------------------------- */

data 'ICN#' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"01FF FF00 0100 0100 0100 0100 010E E100"            /* ................ */
	$"0511 1100 0511 1100 0517 D100 0517 D100"            /* .............. */
	$"071E F100 0120 0900 0130 1900 012F E900"            /* ..... ..0.../.. */
	$"0F10 11E0 11FF FF10 2400 0048 42AA AA84"            /* ........$..HB */
	$"8000 0002 8000 0002 AAAA AAAA 8000 0002"            /* ......... */
	$"8000 0002 9C00 0002 8000 0002 7FFF FFFC"            /* ............. */
	$"1000 0010 2000 0008 2000 0008 1FFF FFF0"            /* .... ... ....... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"01FF FF00 01FF FF00 01FF FF00 01FF FF00"            /* ................ */
	$"05FF FF00 05FF FF00 05FF FF00 05FF FF00"            /* ................ */
	$"07FF FF00 01FF FF00 01FF FF00 01FF FF00"            /* ................ */
	$"0FFF FFE0 1FFF FFF0 3FFF FFF8 7FFF FFFC"            /* ........?....... */
	$"FFFF FFFE FFFF FFFE FFFF FFFE FFFF FFFE"            /* ................ */
	$"FFFF FFFE FFFF FFFE FFFF FFFE 7FFF FFFC"            /* ................ */
	$"1FFF FFF0 3FFF FFF8 3FFF FFF8 1FFF FFF0"            /* ....?...?....... */
};

data 'icl4' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 000F FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 000F 0C0C 0C0C 0C0C 0C0F 0000 0000"            /* ................ */
	$"0000 000F C0C0 C0C0 C0C0 C0CF 0000 0000"            /* ........ */
	$"0000 000F 0C0C FFFC FFFC 0C0F 0000 0000"            /* ................ */
	$"0000 0F0F C0CF 000F 000F C0CF 0000 0000"            /* ............ */
	$"0000 0F0F 0C0F 000F 000F 0C0F 0000 0000"            /* ................ */
	$"0000 0F0F C0CF 0FFF FF0F C0CF 0000 0000"            /* ............ */
	$"0000 0F0F 0C0F 0FFF FF0F 0C0F 0000 0000"            /* ................ */
	$"0000 0FFF C008 FFF8 FFF8 C0CF 0000 0000"            /* ............. */
	$"0000 000F 0C88 8888 8888 8C0F 0000 0000"            /* .......... */
	$"0000 000F C088 8888 8888 80CF 0000 0000"            /* ........ */
	$"0000 000F 0CEE 8888 888E EC0F 0000 0000"            /* ............ */
	$"0000 FFFF C008 EEEE EEE8 00CF FFF0 0000"            /* .............. */
	$"000F 001F FFFF FFFF FFFF FFFF 001F 0000"            /* ................ */
	$"00F0 1B00 1000 1000 1000 1000 1B00 F000"            /* ................ */
	$"0F10 00B0 B0B0 B0B0 B0B0 B0B0 B010 0F00"            /* ...... */
	$"F000 1000 1000 1000 1000 1000 1000 10F0"            /* ................ */
	$"F010 0010 0010 0010 0010 0010 0010 00F0"            /* ................ */
	$"F0B0 B0B0 B0B0 B0B0 B0B0 B0B0 B0B0 B0F0"            /* .. */
	$"F010 0010 0010 0010 0010 0010 0010 00F0"            /* ................ */
	$"F000 1000 1000 1000 1000 1000 1000 10F0"            /* ................ */
	$"F016 6610 0010 0010 0010 0010 0010 00F0"            /* ..f............. */
	$"F000 1000 1000 1000 1000 1000 1000 10F0"            /* ................ */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"000F EEEE EEEE EEEE EEEE EEEE EEEF 0000"            /* ................ */
	$"00FD DDDD DDDD DDDD DDDD DDDD DDDD F000"            /* ................ */
	$"00FC CCCC CCCC CCCC CCCC CCCC CCCC F000"            /* .... */
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
};

data 'icl8' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 00F7 00F7 00F7"            /* ................ */
	$"00F7 00F7 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF F700 F700 F700 F700"            /* ................ */
	$"F700 F700 F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 00F7 FFFF FFF7"            /* ................ */
	$"FFFF FFF7 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF F700 F7FF 0000 00FF"            /* ................ */
	$"0000 00FF F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF 00F7 00FF 0000 00FF"            /* ................ */
	$"0000 00FF 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF F700 F7FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF 00F7 00FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF F700 00E4 FFFF FFE4"            /* ................ */
	$"FFFF FFE4 F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E4F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF F700 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E400 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 A5A5 E4E4 E4E4"            /* .............. */
	$"E4E4 E4A5 A5F7 00FF 0000 0000 0000 0000"            /* .............. */
	$"0000 0000 FFFF FFFF F700 00E4 A5A5 A5A5"            /* ............ */
	$"A5A5 A5E4 0000 F7FF FFFF FF00 0000 0000"            /* ............. */
	$"0000 00FF 0101 01FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0101 01FF 0000 0000"            /* ................ */
	$"0000 FF01 0133 0101 0101 0101 0101 0101"            /* .....3.......... */
	$"0101 0101 0101 0101 0133 0101 FF00 0000"            /* .........3...... */
	$"00FF 0101 0101 3301 3301 3301 3301 3301"            /* ......3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 0101 01FF 0000"            /* 3.3.3.3.3....... */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 3301 3301 3301 3301 3301 3301 3301"            /* ..3.3.3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 3301 3301 FF00"            /* 3.3.3.3.3.3.3... */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 01EC ECEC 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 00FF FBFB FBFB FBFB FBFB FBFB FBFB"            /* ................ */
	$"FBFB FBFB FBFB FBFB FBFB FBFF 0000 0000"            /* ................ */
	$"0000 FFF9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9"            /* ................ */
	$"F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 FF00 0000"            /* ................ */
	$"0000 FFF7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7"            /* ................ */
	$"F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 FF00 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
};

data 'ics#' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0FF8 0808 2808 2948 3808 0A28 19CC"            /* ......(.)H8..(. */
	$"2FFA 4001 5555 4001 5801 7FFF 3FFE 0000"            /* /.@.UU@.X...?... */
	$"0000 0FF8 0FF8 2FF8 2FF8 3FF8 0FF8 1FFC"            /* .....././.?..... */
	$"3FFE 7FFF 7FFF 7FFF 7FFF 7FFF 3FFE 0000"            /* ?...........?... */
};

data 'ics4' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 FFFF FFFF F000"            /* ................ */
	$"0000 F000 0000 F000 00F0 F0CE CEC0 F000"            /* ............. */
	$"00F0 F0E0 E0E0 F000 00FF F0EF EFE0 F000"            /* ................ */
	$"0000 F098 8890 F000 000F F089 9980 FF00"            /* .......... */
	$"00F0 FFFF FFFF F0F0 0F10 0010 0010 001F"            /* ................ */
	$"0F0B 1B0B 1B0B 1B0F 0F10 0010 0010 001F"            /* ................ */
	$"0F0F F000 1000 100F 0FFF FFFF FFFF FFFF"            /* ................ */
	$"00FF FFFF FFFF FFF0 0000 0000 0000 0000"            /* ................ */
};

data 'ics8' (gxPrintingDriverBaseID + 2, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0000 FF00 0000 0000 0000 FF00 0000"            /* ................ */
	$"0000 FF00 FF00 F8FB F8FB F800 FF00 0000"            /* ................ */
	$"0000 FF00 FF00 FB00 FB00 FB00 FF00 0000"            /* ................ */
	$"0000 FFFF FF00 FBFF FBFF FB00 FF00 0000"            /* ................ */
	$"0000 0000 FF00 E7E1 E1E1 E700 FF00 0000"            /* ................ */
	$"0000 00FF FF00 E1E7 E7E7 E100 FFFF 0000"            /* ................ */
	$"0000 FF01 FFFF FFFF FFFF FFFF FF01 FF00"            /* ................ */
	$"00FF 0101 0101 0101 0101 0101 0101 01FF"            /* ................ */
	$"00FF 0133 0133 0133 0133 0133 0133 01FF"            /* ...3.3.3.3.3.3.. */
	$"00FF 0101 0101 0101 0101 0101 0101 01FF"            /* ................ */
	$"00FF 01FF FF01 0101 0101 0101 0101 01FF"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'ICN#' (gxPrintingDriverBaseID + 3, sysheap, purgeable ) {
	$"01FF FF00 0100 0100 0100 0100 010E E100"            /* ................ */
	$"0511 1100 0511 1100 0517 D100 0517 D100"            /* .............. */
	$"071F F100 013F F900 013F F900 013F F900"            /* .....?...?...?.. */
	$"0F1F F1E0 11FF FF10 2000 0008 4000 0004"            /* ........ ...@... */
	$"8000 0002 8000 0002 8000 0002 8000 0002"            /* ............ */
	$"8000 0002 9C00 0002 8000 0002 7FFF FFFC"            /* ............. */
	$"1FFF FFF0 2000 0008 1FFF FFF0 0000 02A0"            /* .... .......... */
	$"BFFF FC9D 0000 0140 BFFF FE3D 0000 0000"            /* .....@..=.... */
	$"01FF FF00 01FF FF00 01FF FF00 01FF FF00"            /* ................ */
	$"05FF FF00 05FF FF00 05FF FF00 05FF FF00"            /* ................ */
	$"07FF FF00 01FF FF00 01FF FF00 01FF FF00"            /* ................ */
	$"0FFF FFE0 1FFF FFF0 3FFF FFF8 7FFF FFFC"            /* ........?....... */
	$"FFFF FFFE FFFF FFFE FFFF FFFE FFFF FFFE"            /* ................ */
	$"FFFF FFFE FFFF FFFE FFFF FFFE 7FFF FFFC"            /* ................ */
	$"1FFF FFF0 3FFF FFF8 1FFF FFF0 0000 03E0"            /* ....?........... */
	$"FFFF FFFF FFFF FF7F FFFF FE3F 0000 0000"            /* ...........?.... */
};

data 'icl4' (gxPrintingDriverBaseID + 3, sysheap, purgeable ) {
	$"0000 000F FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 000F 0C0C 0C0C 0C0C 0C0F 0000 0000"            /* ................ */
	$"0000 000F C0C0 C0C0 C0C0 C0CF 0000 0000"            /* ........ */
	$"0000 000F 0C0C FFFC FFFC 0C0F 0000 0000"            /* ................ */
	$"0000 0F0F C0CF 000F 000F C0CF 0000 0000"            /* ............ */
	$"0000 0F0F 0C0F 000F 000F 0C0F 0000 0000"            /* ................ */
	$"0000 0F0F C0CF 0FFF FF0F C0CF 0000 0000"            /* ............ */
	$"0000 0F0F 0C0F 0FFF FF0F 0C0F 0000 0000"            /* ................ */
	$"0000 0FFF C008 FFF8 FFF8 C0CF 0000 0000"            /* ............. */
	$"0000 000F 0C88 8888 8888 8C0F 0000 0000"            /* .......... */
	$"0000 000F C088 8888 8888 80CF 0000 0000"            /* ........ */
	$"0000 000F 0CEE 8888 888E EC0F 0000 0000"            /* ............ */
	$"0000 FFFF C008 EEEE EEE8 00CF FFF0 0000"            /* .............. */
	$"000F 010F FFFF FFFF FFFF FFFF 010F 0000"            /* ................ */
	$"00F0 1D10 1010 1010 1010 1010 1D10 F000"            /* ................ */
	$"0F01 01D1 D1D1 D1D1 D1D1 D1D1 0101 0F00"            /* ....... */
	$"F010 1010 1010 1010 1010 1010 1010 10F0"            /* ................ */
	$"F101 0101 0101 0101 0101 0101 0101 01F0"            /* ................ */
	$"F0D0 D0D0 D0D0 D0D0 D0D0 D0D0 D0D0 D0F0"            /* .. */
	$"F101 0101 0101 0101 0101 0101 0101 01F0"            /* ................ */
	$"F010 1010 1010 1010 1010 1010 1010 10F0"            /* ................ */
	$"F106 6601 0101 0101 0101 0101 0101 01F0"            /* ..f............. */
	$"F010 1010 1010 1010 1010 1010 1010 10F0"            /* ................ */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"000F EEEE EEEE EEEE EEEE EEEE EEEF 0000"            /* ................ */
	$"00FD DDDD DDDD DDDD DDDD DDDD DDDD F000"            /* ................ */
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 00FC FCE0 0000"            /* ................ */
	$"CCCC CCCC CCDD DDDD EEEE EECC FCCE EEEE"            /* ......... */
	$"0000 00CC CCCC CCCC CCCC CCCF 0FCC CCCC"            /* .... */
	$"CCCC CDDD DDDE EEEE EEEE EFF0 00FE EEEE"            /* ............. */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl8' (gxPrintingDriverBaseID + 3, sysheap, purgeable ) {
	$"0000 0000 0000 00FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 00F7 00F7 00F7"            /* ................ */
	$"00F7 00F7 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF F700 F700 F700 F700"            /* ................ */
	$"F700 F700 F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 00F7 FFFF FFF7"            /* ................ */
	$"FFFF FFF7 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF F700 F7FF 0000 00FF"            /* ................ */
	$"0000 00FF F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF 00F7 00FF 0000 00FF"            /* ................ */
	$"0000 00FF 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF F700 F7FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF 00FF 00F7 00FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF 00F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF F700 00E4 FFFF FFE4"            /* ................ */
	$"FFFF FFE4 F700 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E4F7 00FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF F700 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E400 F7FF 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 00FF 00F7 A5A5 E4E4 E4E4"            /* .............. */
	$"E4E4 E4A5 A5F7 00FF 0000 0000 0000 0000"            /* .............. */
	$"0000 0000 FFFF FFFF F700 00E4 A5A5 A5A5"            /* ............ */
	$"A5A5 A5E4 0000 F7FF FFFF FF00 0000 0000"            /* ............. */
	$"0000 00FF 0101 01FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0101 01FF 0000 0000"            /* ................ */
	$"0000 FF01 0133 0101 0101 0101 0101 0101"            /* .....3.......... */
	$"0101 0101 0101 0101 0133 0101 FF00 0000"            /* .........3...... */
	$"00FF 0101 0101 3301 3301 3301 3301 3301"            /* ......3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 0101 01FF 0000"            /* 3.3.3.3.3....... */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 3301 3301 3301 3301 3301 3301 3301"            /* ..3.3.3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 3301 3301 FF00"            /* 3.3.3.3.3.3.3... */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 01EC ECEC 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"FF01 0101 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 0101 FF00"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 00FF FBFB FBFB FBFB FBFB FBFB FBFB"            /* ................ */
	$"FBFB FBFB FBFB FBFB FBFB FBFF 0000 0000"            /* ................ */
	$"0000 FFF9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9"            /* ................ */
	$"F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 FF00 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF2B FE2B FD00 0000 0000"            /* .......+.+...... */
	$"F6F6 F6F6 F7F7 F7F8 F8F8 F9F9 F9FA FAFA"            /* ................ */
	$"FBFB FBFC FCFC 2B2B FE2B 2BFD FDFC FCFC"            /* ......++.++..... */
	$"F5F5 F5F5 F5F5 F6F6 F6F6 F6F6 F62B 2B2B"            /* .............+++ */
	$"2B2B 2B2B 2B2B 2BFE 00FE 2B2B 2B2B 2B2B"            /* +++++++...++++++ */
	$"F7F7 F8F8 F8F9 F9F9 FAFA FAFB FBFB FCFC"            /* ................ */
	$"FCFD FDFD FEFE FE00 0000 FEFE FDFD FCFC"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'ICN#' (gxPrintingDriverBaseID + 4, sysheap, purgeable ) {
	$"0000 0000 0000 0000 03FF FF80 07FF FFC0"            /* .............. */
	$"07FF FFC0 0700 01C0 0700 01C0 470E E1C0"            /* .........G.. */
	$"E711 11C0 E711 11C0 E717 D1C0 FF17 D1C0"            /* .......... */
	$"FF1F F1C0 7F3F F9C0 073F F9E0 073F F9F0"            /* ....?..?...?.. */
	$"0F1F F1F8 1DFF FF3C 3C00 004E 72AA AA87"            /* .......<<..Nr */
	$"E000 0007 E000 0007 EAAA AAAF E000 0007"            /* ............. */
	$"E000 0007 FC00 0007 E000 0007 FFFF FFFF"            /* ................ */
	$"FFFF FFFE FFFF FFFE FFFF FFFE 7FFF FFFC"            /* ................ */
	$"0000 0000 0000 0000 03FF FF80 07FF FFC0"            /* .............. */
	$"07FF FFC0 07FF FFC0 07FF FFC0 47FF FFC0"            /* .........G.. */
	$"E7FF FFC0 E7FF FFC0 E7FF FFC0 FFFF FFC0"            /* ............ */
	$"FFFF FFC0 7FFF FFC0 07FF FFE0 07FF FFF0"            /* .............. */
	$"0FFF FFF8 1FFF FFFC 3FFF FFFE 7FFF FFFF"            /* ........?....... */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFE FFFF FFFE FFFF FFFE 7FFF FFFC"            /* ................ */
};

data 'icl4' (gxPrintingDriverBaseID + 4, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF FFFF FFFF F000 0000"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0FFF 0C0C 0C0C 0C0C 0C0F FF00 0000"            /* ................ */
	$"0000 0FFF C0C0 C0C0 C0C0 C0CF FF00 0000"            /* ........ */
	$"0F00 0FFF 0C0C FFFC FFFC 0C0F FF00 0000"            /* ................ */
	$"FFF0 0FFF C0CF 000F 000F C0CF FF00 0000"            /* ............ */
	$"FFF0 0FFF 0C0F 000F 000F 0C0F FF00 0000"            /* ................ */
	$"FFF0 0FFF C0CF 0FFF FF0F C0CF FF00 0000"            /* ............ */
	$"FFFF FFFF 0C0F 0FFF FF0F 0C0F FF00 0000"            /* ................ */
	$"FFFF FFFF C008 FFF8 FFF8 C0CF FF00 0000"            /* ............. */
	$"0FFF FFFF 0C88 8888 8888 8C0F FF00 0000"            /* .......... */
	$"0000 0FFF C088 8888 8888 80CF FFF0 0000"            /* ........ */
	$"0000 0FFF 0CEE 8888 888E EC0F FFFF 0000"            /* ............ */
	$"0000 FFFF C008 EEEE EEE8 00CF FFFF F000"            /* .............. */
	$"000F FF0F FFFF FFFF FFFF FFFF 01DF FF00"            /* ................ */
	$"00FF FD10 1010 1010 1010 1010 1D10 FFF0"            /* ................ */
	$"0FFF 01D1 D1D1 D1D1 D1D1 D1D1 D101 0FFF"            /* ...... */
	$"FFF0 1010 1010 1010 1010 1010 1010 1FFF"            /* ................ */
	$"FFF1 0101 0101 0101 0101 0101 0101 0FFF"            /* ................ */
	$"FFF0 D0D0 D0D0 D0D0 D0D0 D0D0 D0D0 DFFF"            /* .... */
	$"FFF1 0101 0101 0101 0101 0101 0101 0FFF"            /* ................ */
	$"FFF0 1010 1010 1010 1010 1010 1010 1FFF"            /* ................ */
	$"FFF6 6601 0101 0101 0101 0101 0101 0FFF"            /* ..f............. */
	$"FFF0 1010 1010 1010 1010 1010 1010 1FFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF EEEE EEEE EEEE EEEE EEEE EEEF FFF0"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
};

data 'icl8' (gxPrintingDriverBaseID + 4, sysheap, purgeable ) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF 00F7 00F7 00F7 00F7"            /* ................ */
	$"00F7 00F7 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF F700 F700 F700 F700"            /* ................ */
	$"F700 F700 F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"00FF 0000 00FF FFFF 00F7 00F7 FFFF FFF7"            /* ................ */
	$"FFFF FFF7 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FF00 00FF FFFF F700 F7FF 0000 00FF"            /* ................ */
	$"0000 00FF F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FF00 00FF FFFF 00F7 00FF 0000 00FF"            /* ................ */
	$"0000 00FF 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FF00 00FF FFFF F700 F7FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FFFF FFFF FFFF 00F7 00FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FFFF FFFF FFFF F700 00E4 FFFF FFE4"            /* ................ */
	$"FFFF FFE4 F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF 00F7 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E4F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF F700 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E400 F7FF FFFF FF00 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF 00F7 A5A5 E4E4 E4E4"            /* .............. */
	$"E4E4 E4A5 A5F7 00FF FFFF FFFF 0000 0000"            /* .............. */
	$"0000 0000 FFFF FFFF F700 00E4 A5A5 A5A5"            /* ............ */
	$"A5A5 A5E4 0000 F7FF FFFF FFFF FF00 0000"            /* ............. */
	$"0000 00FF FFFF 01FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0101 33FF FFFF 0000"            /* ..........3..... */
	$"0000 FFFF FF33 0101 0101 0101 0101 0101"            /* .....3.......... */
	$"0101 0101 0101 0101 0133 0101 FFFF FF00"            /* .........3...... */
	$"00FF FFFF 0101 3301 3301 3301 3301 3301"            /* ......3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 0101 01FF FFFF"            /* 3.3.3.3.3....... */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 3301 3301 3301 3301 3301 3301"            /* ....3.3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 3301 33FF FFFF"            /* 3.3.3.3.3.3.3... */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FFEC ECEC 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FBFB FBFB FBFB FBFB FBFB FBFB"            /* ................ */
	$"FBFB FBFB FBFB FBFB FBFB FBFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
};

data 'ICN#' (gxPrintingDriverBaseID + 5, sysheap, purgeable ) {
	$"07FF FFC0 07FF FFC0 07FF FFC0 4700 01C0"            /* .........G.. */
	$"E70E E1C0 E711 11C0 FF17 D1C0 FF17 D1C0"            /* .......... */
	$"7F1F F1C0 0F3F F9C0 1F3F F9E0 3F3F F9F0"            /* ....?..?..??.. */
	$"7F1F F1F8 F1FF FF3C E800 003E E555 554F"            /* .......<...>.UUO */
	$"E000 0007 E000 0007 EAAA AAAF E000 0007"            /* ............. */
	$"E000 0007 FC00 0007 E000 000F FFFF FFFF"            /* ................ */
	$"FFFF FFFF 7FFF FFFE 3FFF FFFC 0000 02A0"            /* ........?...... */
	$"BFFF FC9D 0000 0140 BFFF FE3D 0000 0000"            /* .....@..=.... */
	$"07FF FFC0 07FF FFC0 07FF FFC0 47FF FFC0"            /* .........G.. */
	$"E7FF FFC0 E7FF FFC0 FFFF FFC0 FFFF FFC0"            /* ............ */
	$"7FFF FFC0 0FFF FFC0 1FFF FFE0 3FFF FFF0"            /* ..........?... */
	$"7FFF FFF8 FFFF FFFC FFFF FFFE FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF 7FFF FFFE 3FFF FFFC 0000 03E0"            /* ........?....... */
	$"FFFF FFFF FFFF FF7F FFFF FE3F 0000 0000"            /* ...........?.... */
};

data 'icl4' (gxPrintingDriverBaseID + 5, sysheap, purgeable ) {
	$"0000 0FFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0000 0FFF FFFF FFFF FFFF FFFF FF00 0000"            /* ................ */
	$"0F00 0FFF 0C00 0000 0000 0C0F FF00 0000"            /* ................ */
	$"FFF0 0FFF C0CC FFFC FFFC C0CF FF00 0000"            /* ............ */
	$"FFF0 0FFF 0C0F 000F 000F 0C0F FF00 0000"            /* ................ */
	$"FFFF FFFF C0CF 0FFF FF0F C0CF FF00 0000"            /* ............ */
	$"FFFF FFFF 0C0F 0FFF FF0F 0C0F FF00 0000"            /* ................ */
	$"0FFF FFFF C008 FFF8 FFF8 C0CF FF00 0000"            /* ............. */
	$"0000 FFFF 0C88 8888 8888 8C0F FF00 0000"            /* .......... */
	$"000F FFFF C088 8888 8888 80CF FFF0 0000"            /* ........ */
	$"00FF FFFF 0CEE 8888 888E EC0F FFFF 0000"            /* ............ */
	$"0FFF FFFF C008 EEEE EEE8 00CF FFFF F000"            /* .............. */
	$"FFFF 010F FFFF FFFF FFFF FFFF 01FF FF00"            /* ................ */
	$"FFF0 1D10 1010 1010 1010 1010 1D1F FFF0"            /* ................ */
	$"FFF1 01D1 D1D1 D1D1 D1D1 D1D1 D101 FFFF"            /* ...... */
	$"FFF0 1010 1010 1010 1010 1010 1010 1FFF"            /* ................ */
	$"FFF1 0101 0101 0101 0101 0101 0101 0FFF"            /* ................ */
	$"FFF0 D0D0 D0D0 D0D0 D0D0 D0D0 D0D0 DFFF"            /* .... */
	$"FFF1 0101 0101 0101 0101 0101 0101 0FFF"            /* ................ */
	$"FFF0 1010 1010 1010 1010 1010 1010 1FFF"            /* ................ */
	$"FFF6 6601 0101 0101 0101 0101 0101 0FFF"            /* ..f............. */
	$"FFF0 1010 1010 1010 1010 1010 1010 FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"0FFF FFFF FFFF FFFF FFFF FFFF FFFF FFF0"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 0000 0000 0000 0000 00FC FCA0 0000"            /* ............... */
	$"CCCC CCCC CCDD DDDD EEEE EECC FCCA AEEE"            /* .......ʮ. */
	$"0000 00CC CCCC CCCC CCCC CCCF 0FCC CCCC"            /* .... */
	$"CCCC CDDD DDDE EEEE EAAA FFF0 00FF AAEE"            /* ........... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl8' (gxPrintingDriverBaseID + 5, sysheap, purgeable ) {
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 00FF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF 0000 0000 0000"            /* ................ */
	$"00FF 0000 00FF FFFF 00F7 0000 0000 0000"            /* ................ */
	$"0000 0000 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FF00 00FF FFFF F700 F7F7 FFFF FFF7"            /* ................ */
	$"FFFF FFF7 F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FF00 00FF FFFF 00F7 00FF 0000 00FF"            /* ................ */
	$"0000 00FF 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FFFF FFFF FFFF F700 F7FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"FFFF FFFF FFFF FFFF 00F7 00FF 00FF FFFF"            /* ................ */
	$"FFFF 00FF 00F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"00FF FFFF FFFF FFFF F700 00E4 FFFF FFE4"            /* ................ */
	$"FFFF FFE4 F700 F7FF FFFF 0000 0000 0000"            /* ................ */
	$"0000 0000 FFFF FFFF 00F7 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E4F7 00FF FFFF 0000 0000 0000"            /* ................ */
	$"0000 00FF FFFF FFFF F700 E4E4 E4E4 E4E4"            /* ................ */
	$"E4E4 E4E4 E400 F7FF FFFF FF00 0000 0000"            /* ................ */
	$"0000 FFFF FFFF FFFF 00F7 A5A5 E4E4 E4E4"            /* .............. */
	$"E4E4 E4A5 A5F7 00FF FFFF FFFF 0000 0000"            /* .............. */
	$"00FF FFFF FFFF FFFF F700 00E4 A5A5 A5A5"            /* ............ */
	$"A5A5 A5E4 0000 F7FF FFFF FFFF FF00 0000"            /* ............. */
	$"FFFF FFFF 0101 01FF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF 0101 FFFF FFFF 0000"            /* ................ */
	$"FFFF FF01 0133 0101 0101 0101 0101 0101"            /* .....3.......... */
	$"0101 0101 0101 0101 0133 01FF FFFF FF00"            /* .........3...... */
	$"FFFF FF01 0101 3301 3301 3301 3301 3301"            /* ......3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 0101 FFFF FFFF"            /* 3.3.3.3.3....... */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 3301 3301 3301 3301 3301 3301"            /* ....3.3.3.3.3.3. */
	$"3301 3301 3301 3301 3301 3301 33FF FFFF"            /* 3.3.3.3.3.3.3... */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FFEC ECEC 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 01FF FFFF"            /* ................ */
	$"FFFF FF01 0101 0101 0101 0101 0101 0101"            /* ................ */
	$"0101 0101 0101 0101 0101 0101 FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FF00"            /* ................ */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /* ................ */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 FF2B FE2B FD00 0000 0000"            /* .......+.+...... */
	$"F6F6 F6F6 F7F7 F7F8 F8F8 F9F9 F9FA FAFA"            /* ................ */
	$"FBFB FBFC FCFC 2B2B FE2B 2BFD FDFC FCFC"            /* ......++.++..... */
	$"F5F5 F5F5 F5F5 F6F6 F6F6 F6F6 F62B 2B2B"            /* .............+++ */
	$"2B2B 2B2B 2B2B 2BFE 00FE 2B2B 2B2B 2B2B"            /* +++++++...++++++ */
	$"F7F7 F8F8 F8F9 F9F9 FAFA FAFB FBFB FCFC"            /* ................ */
	$"FCFD FDFD FEFE FE00 0000 FEFE FDFD FCFC"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

resource 'ICN#' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"6000 0006 F000 000F F800 001F 7C00 003E 3FFF FF7C 1F00 01F8 0F80"
		$"01F0 07CE E3E0 07F1 17C0 05F1 1F80 05FF DF00 057D BF00 073E 7D00"
		$"011F F900 012F F900 012F E900 0F17 F1E0 11FF FF10 201F F808 403E"
		$"7C04 D57D BEAA 80F8 1F02 81F0 0F82 83E0 07C2 87C0 03E2 9F80 01F2"
		$"9F00 00FA 7FFF FFFC 7FFF FFFE F800 001F F000 000F 7FFF FFF6",
		/* [2] */
		$"6000 0006 F000 000F F800 001F 7C00 003E 3FFF FF7C 1FFF FFF8 0FFF"
		$"FFF0 07FF FFE0 07FF FFC0 07FF FF80 07FF FF00 07FF FF00 07FF FF00"
		$"01FF FF00 01FF FF00 01FF FF00 0FFF FFE0 1FFF FFF0 3FFF FFF8 7FFF"
		$"FFFC FFFF FFFE FFFF FFFE FFFF FFFE FFFF FFFE FFFF FFFE FFFF FFFE"
		$"FFFF FFFE 7FFF FFFC 7FFF FFFE FFFF FFFF FFFF FFFF 7FFF FFF6"
	}
};

resource 'ICN#' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"00FF FF00 0100 0080 0080 0100 7F80 01FE 8000 0001 81FF FF01 8100"
		$"0101 8100 0101 810E E101 8511 1101 8511 1101 8517 D101 8517 D101"
		$"871E 7101 8120 0901 8120 0901 8110 1101 8F1F F1E1 91FF FF11 A000"
		$"0009 B555 5555 A000 0005 A000 0005 A055 5555 AE00 0005 A000 0005"
		$"9FFF FFF9 8000 0001 80FF FF01 8080 0101 8040 0201 7FE0 07FE",
		/* [2] */
		$"00FF FF00 01FF FF80 00FF FF00 7FFF FFFE FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FF80 01FF FFC0 03FF 7FE0 07FE"
	}
};

resource 'icl4' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	$"0FF0 0000 0000 0000 0000 0000 0000 0FF0 FFFF 0000 0000 0000 0000"
	$"0000 0000 FFFF FFFF F000 0000 0000 0000 0000 000F FFFF 0FFF FF00"
	$"0000 0000 0000 0000 00FF FFF0 00FF FFFF FFFF FFFF FFFF FFFF 0FFF"
	$"FF00 000F FFFF 0C0C 0C0C 0C0C 0C0F FFFF F000 0000 FFFF F0C0 C0C0"
	$"C0C0 C0CF FFFF 0000 0000 0FFF FF0C FFFC FFFC 0CFF FFF0 0000 0000"
	$"0FFF FFFF 000F 000F CFFF FF00 0000 0000 0F0F FFFF 000F 000F FFFF"
	$"F000 0000 0000 0F0F FFFF FFFF FF0F FFFF 0000 0000 0000 0F0F 0FFF"
	$"FFFF FFFF FFFF 0000 0000 0000 0FFF C0FF FFF8 FFFF FFCF 0000 0000"
	$"0000 000F 0C8F FFFF FFFF FC0F 0000 0000 0000 000F C088 FFFF FFFF"
	$"80CF 0000 0000 0000 000F 0CEE 8FFF FFFE EC0F 0000 0000 0000 FFFF"
	$"C008 EFFF FFF8 00CF FFF0 0000 000F 010F FFFF FFFF FFFF FFFF 010F"
	$"0000 00F0 0D00 000F FFFF FFFF F000 0D00 F000 0F01 01D1 D1FF FFF1"
	$"DFFF FFD1 D101 0F00 F000 0000 0FFF FF00 00FF FFF0 0000 00F0 F101"
	$"0101 FFFF F101 010F FFFF 0101 01F0 F0D0 D0DF FFFF D0D0 D0D0 FFFF"
	$"F0D0 D0F0 F101 01FF FFF1 0101 0101 0FFF FF01 01F0 F000 0FFF FF00"
	$"0000 0000 00FF FFF0 00F0 F106 FFFF F101 0101 0101 010F FFFF 01F0"
	$"F00F FFFF 0000 0000 0000 0000 FFFF F0F0 0FFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0FFF FFEE EEEE EEEE EEEE EEEE EEFF FFF0 FFFF FDDD"
	$"DDDD DDDD DDDD DDDD DDDF FFFF FFFF CCCC CCCC CCCC CCCC CCCC CCCC"
	$"FFFF 0FFF FFFF FFFF FFFF FFFF FFFF FFFF 0FF0"
};

resource 'icl4' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	$"0000 0000 FFFF FFFF FFFF FFFF 0000 0000 0000 000F 0000 0000 0000"
	$"0000 F000 0000 0000 0000 F0C0 C0C0 C0C0 C0CF 0000 0000 0FFF FFFF"
	$"F00C 0C0C 0C0C 0C0F FFFF FFF0 F000 0000 00C0 C0C0 C0C0 C0C0 0000"
	$"000F F00C 0C0F FFFF FFFF FFFF FFFF 0C0C 0C0F F0C0 C0CF 0C0C 0C0C"
	$"0C0C 0C0F C0C0 C0CF F00C 0C0F C0C0 C0C0 C0C0 C0CF 0C0C 0C0F F0C0"
	$"C0CF 0C0C FFFC FFFC 0C0F C0C0 C0CF F00C 0F0F C0CF 000F 000F C0CF"
	$"0C0C 0C0F F0C0 CFCF 0C0F 000F 000F 0C0F C0C0 C0CF F00C 0F0F C0CF"
	$"0FFF FF0F C0CF 0C0C 0C0F F0C0 CFCF 0C0F 0FFF FF0F 0C0F C0C0 C0CF"
	$"F00C 0FFF C008 FFF8 FFF8 C0CF 0C0C 0C0F F0C0 C0CF 0C88 8888 8888"
	$"8C0F C0C0 C0CF F00C 0C0F C088 8888 8888 80CF 0C0C 0C0F F0C0 C0CF"
	$"0CEE 8888 888E EC0F C0C0 C0CF F00C FFFF C008 EEEE EEE8 00CF FFFC"
	$"0C0F F0CF 000F FFFF FFFF FFFF FFFF 000F C0CF F0F1 0D01 0101 0101"
	$"0101 0101 0D01 FC0F F0F0 00D0 D0D0 D0D0 D0D0 D0D0 D000 0FCF F0F1"
	$"0101 0101 0101 0101 0101 0101 0F0F F0F0 0000 0000 0000 0000 0000"
	$"0000 0FCF F0F1 D1D1 D1D1 D1D1 D1D1 D1D1 D1D1 DF0F F0F0 6660 0000"
	$"0000 0000 0000 0000 0FCF F0F1 0101 0101 0101 0101 0101 0101 0F0F"
	$"F0CF FFFF FFFF FFFF FFFF FFFF FFFF F0CF F00C 0C0C 0C0C 0C0C 0C0C"
	$"0C0C 0C0C 0C0F F0C0 C0C0 FFFF FFFF FFFF FFFF C0C0 C0CF F00C 0C0C"
	$"F000 0000 0000 000F 0C0C 0C0F F0C0 C0C0 CF00 0000 0000 00F0 C0C0"
	$"C0CF 0FFF FFFF FFF0 0000 0000 0FFF FFFF FFF0"
};

resource 'icl8' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	$"00FF FF00 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 00FF FF00 FFFF FFFF 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FFFF FFFF FFFF FFFF FF00 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 00FF FFFF FFFF 00FF FFFF FFFF 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 0000 FFFF FFFF FF00 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 00FF FFFF"
	$"FFFF 0000 0000 00FF FFFF FFFF 00F7 00F7 00F7 00F7 00F7 00F7 00F7"
	$"00FF FFFF FFFF FF00 0000 0000 0000 FFFF FFFF FF00 F700 F700 F700"
	$"F700 F700 F700 F7FF FFFF FFFF 0000 0000 0000 0000 00FF FFFF FFFF"
	$"00F7 FFFF FFF7 FFFF FFF7 00F7 FFFF FFFF FF00 0000 0000 0000 0000"
	$"00FF FFFF FFFF FFFF 0000 00FF 0000 00FF F7FF FFFF FFFF 0000 0000"
	$"0000 0000 0000 00FF 00FF FFFF FFFF 0000 00FF 0000 00FF FFFF FFFF"
	$"FF00 0000 0000 0000 0000 0000 00FF 00FF FFFF FFFF FFFF FFFF FFFF"
	$"00FF FFFF FFFF 0000 0000 0000 0000 0000 0000 00FF 00FF 00FF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000 0000 0000 0000 0000 00FF"
	$"FFFF F700 FFFF FFFF FFE4 FFFF FFFF FFFF F7FF 0000 0000 0000 0000"
	$"0000 0000 0000 00FF 00F7 E4FF FFFF FFFF FFFF FFFF FFF7 00FF 0000"
	$"0000 0000 0000 0000 0000 0000 00FF F700 E4E4 FFFF FFFF FFFF FFFF"
	$"E400 F7FF 0000 0000 0000 0000 0000 0000 0000 00FF 00F7 A5A5 E4FF"
	$"FFFF FFFF FFA5 A5F7 00FF 0000 0000 0000 0000 0000 0000 FFFF FFFF"
	$"F700 00E4 A5FF FFFF FFFF FFE4 0000 F7FF FFFF FF00 0000 0000 0000"
	$"00FF 0101 01FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0101 01FF"
	$"0000 0000 0000 FF01 0133 0101 0101 01FF FFFF FFFF FFFF FFFF FF01"
	$"0101 0133 0101 FF00 0000 00FF 0101 0101 3301 3301 FFFF FFFF FF01"
	$"33FF FFFF FFFF 3301 3301 0101 01FF 0000 FF01 0101 0101 0101 01FF"
	$"FFFF FFFF 0101 0101 FFFF FFFF FF01 0101 0101 0101 FF00 FF01 0101"
	$"0101 0101 FFFF FFFF FF01 0101 0101 01FF FFFF FFFF 0101 0101 0101"
	$"FF00 FF01 3301 3301 33FF FFFF FFFF 3301 3301 3301 3301 FFFF FFFF"
	$"FF01 3301 3301 FF00 FF01 0101 0101 FFFF FFFF FF01 0101 0101 0101"
	$"0101 01FF FFFF FFFF 0101 0101 FF00 FF01 0101 01FF FFFF FFFF 0101"
	$"0101 0101 0101 0101 0101 FFFF FFFF FF01 0101 FF00 FF01 01EC FFFF"
	$"FFFF FF01 0101 0101 0101 0101 0101 0101 01FF FFFF FFFF 0101 FF00"
	$"FF01 01FF FFFF FFFF 0101 0101 0101 0101 0101 0101 0101 0101 FFFF"
	$"FFFF FF01 FF00 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF 0000 00FF FFFF FFFF FBFB FBFB FBFB FBFB"
	$"FBFB FBFB FBFB FBFB FBFB FBFB FFFF FFFF FF00 FFFF FFFF FFF9 F9F9"
	$"F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9F9 F9FF FFFF FFFF FFFF"
	$"FFFF F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7 F7F7"
	$"FFFF FFFF 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF 00FF FF"
};

resource 'icl8' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	$"0000 0000 0000 0000 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"
	$"0000 0000 0000 0000 0000 0000 00FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 FF00 0000 0000 0000 0000 0000 0000 0000 FF00 2B00 2B00"
	$"2B00 2B00 2B00 2B00 2BFF 0000 0000 0000 0000 00FF FFFF FFFF FFFF"
	$"FF00 002B 002B 002B 002B 002B 002B 00FF FFFF FFFF FFFF FF00 FF00"
	$"0000 0000 0000 0000 2B00 2B00 2B00 2B00 2B00 2B00 2B00 0000 0000"
	$"0000 00FF FF00 002B 002B 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF 002B 002B 002B 00FF FF00 2B00 2B00 2BFF 00F7 00F7 00F7 00F7"
	$"00F7 00F7 00F7 00FF 2B00 2B00 2B00 2BFF FF00 002B 002B 00FF F700"
	$"F700 F700 F700 F700 F700 F700 F7FF 002B 002B 002B 00FF FF00 2B00"
	$"2B00 2BFF 00F7 00F7 FFFF FFF7 FFFF FFF7 00F7 00FF 2B00 2B00 2B00"
	$"2BFF FF00 002B 00FF 00FF F700 F7FF 0000 00FF 0000 00FF F700 F7FF"
	$"002B 002B 002B 00FF FF00 2B00 2BFF 2BFF 00F7 00FF 0000 00FF 0000"
	$"00FF 00F7 00FF 2B00 2B00 2B00 2BFF FF00 002B 00FF 00FF F700 F7FF"
	$"00FF FFFF FFFF 00FF F700 F7FF 002B 002B 002B 00FF FF00 2B00 2BFF"
	$"2BFF 00F7 00FF 00FF FFFF FFFF 00FF 00F7 00FF 2B00 2B00 2B00 2BFF"
	$"FF00 002B 00FF FFFF F700 00E4 FFFF FFE4 FFFF FFE4 F700 F7FF 002B"
	$"002B 002B 00FF FF00 2B00 2B00 2BFF 00F7 E4E4 E4E4 E4E4 E4E4 E4E4"
	$"E4F7 00FF 2B00 2B00 2B00 2BFF FF00 002B 002B 00FF F700 E4E4 E4E4"
	$"E4E4 E4E4 E4E4 E400 F7FF 002B 002B 002B 00FF FF00 2B00 2B00 2BFF"
	$"00F7 A5A5 E4E4 E4E4 E4E4 E4A5 A5F7 00FF 2B00 2B00 2B00 2BFF FF00"
	$"002B FFFF FFFF F700 00E4 A5A5 A5A5 A5A5 A5E4 0000 F7FF FFFF FF2B"
	$"002B 00FF FF00 2BFF 0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF 0000 00FF 2B00 2BFF FF00 FF05 00F9 0005 0005 0005 0005 0005"
	$"0005 0005 0005 0005 00F9 0005 FF2B 00FF FF00 FF00 0000 F900 F900"
	$"F900 F900 F900 F900 F900 F900 F900 F900 0000 00FF 2BFF FF00 FF05"
	$"0005 0005 0005 0005 0005 0005 0005 0005 0005 0005 0005 0005 00FF"
	$"00FF FF00 FF00 0000 0000 0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 00FF 2BFF FF00 FF05 F905 F905 F905 F905 F905 F905 F905"
	$"F905 F905 F905 F905 F905 F9FF 00FF FF00 FF00 ECEC EC00 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000 00FF 2BFF FF00 FF05 0005"
	$"0005 0005 0005 0005 0005 0005 0005 0005 0005 0005 0005 00FF 00FF"
	$"FF00 2BFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FF00 2BFF FF00 002B 002B 002B 002B 002B 002B 002B 002B 002B"
	$"002B 002B 002B 002B 002B 00FF FF00 2B00 2B00 2B00 FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF 2B00 2B00 2B00 2BFF FF00 002B 002B 002B"
	$"FF00 0000 0000 0000 0000 0000 0000 00FF 002B 002B 002B 00FF FF00"
	$"2B00 2B00 2B00 2BFF 0000 0000 0000 0000 0000 0000 FF00 2B00 2B00"
	$"2B00 2BFF 00FF FFFF FFFF FFFF FFFF FF00 0000 0000 0000 0000 00FF"
	$"FFFF FFFF FFFF FFFF FF"
};

resource 'ics#' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"C003 E007 7FFE 3BDC 1D78 1FF0 17F0 17D0 7FFC C7E2 8E71 9C39 B81D"
		$"FFFF C003 FFFF",
		/* [2] */
		$"C003 E007 7FFE 3FFC 1FF8 1FF0 1FF0 1FF0 7FFC FFFE FFFF FFFF FFFF"
		$"FFFF FFFF FFFF"
	}
};

resource 'ics#' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"1FF8 F81F 8001 9FF1 B011 B6D1 B551 97D1 B7DD BFF5 A005 A805 BFFD"
		$"8001 8FF1 FC3F",
		/* [2] */
		$"1FF8 FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FC3F"
	}
};

resource 'ics4' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	$"FF00 0000 0000 00FF FFF0 0000 0000 0FFF 0FFF FFFF FFFF FFF0 00FF"
	$"FCFF FFCF FF00 000F FF0F 0FFF F000 000F FFFF FFFF 0000 000F CFFF"
	$"FFFF 0000 000F C8FF FFCF 0000 0FFF FFFF FFFF FF00 FFDD DFFF FFFD"
	$"D1F0 F010 FFF0 0FFF 101F FDDF FFDD DDFF FDDF F6FF F010 101F FF0F"
	$"FFFF FFFF FFFF FFFF FFFE EEEE EEEE EFFF FFFF FFFF FFFF FFFF"
};

resource 'ics4' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	$"000F FFFF FFFF F000 FFFF FCCC CCCF FFFF FCCC CCCC CCCC CCCF FCCF"
	$"FFFF FFFF CCCF FCFF CCCC CCCF CCCF FCFF CFFC FFCF CCCF FCFF CF0F"
	$"0FCF CCCF FCCF C888 88CF CCCF FCFF CEEE EEEF FFCF FCFF FFFF FFFF"
	$"0FCF FCF0 1000 1000 1FCF FCF0 6010 0010 0FCF FCFF FFFF FFFF FFCF"
	$"FCCC CCCC CCCC CCCF FCCC FFFF FFFF CCCF FFFF FF00 00FF FFFF"
};

resource 'ics8' (gxPrintingDriverBaseID + 6, sysheap, purgeable) {
	$"FFFF 0000 0000 0000 0000 0000 0000 FFFF FFFF FF00 0000 0000 0000"
	$"0000 00FF FFFF 00FF FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000 FFFF"
	$"FFF7 FFFF FFFF F7FF FFFF 0000 0000 00FF FFFF 00FF 00FF FFFF FF00"
	$"0000 0000 00FF FFFF FFFF FFFF FFFF 0000 0000 0000 00FF F7FF FFFF"
	$"FFFF FFFF 0000 0000 0000 00FF F7E4 FFFF FFFF F7FF 0000 0000 00FF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 FFFF 3333 33FF FFFF FFFF FF33"
	$"3301 FF00 FF01 0101 FFFF FF01 01FF FFFF 0101 01FF FF33 33FF FFFF"
	$"3333 3333 FFFF FF33 33FF FFEC FFFF FF01 0101 0101 01FF FFFF 01FF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFB FBFB FBFB FBFB"
	$"FBFB FBFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics8' (gxPrintingDriverBaseID + 7, sysheap, purgeable) {
	$"0000 00FF FFFF FFFF FFFF FFFF FF00 0000 FFFF FFFF FF2B 2B2B 2B2B"
	$"2BFF FFFF FFFF FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FF2B 2BFF"
	$"FFFF FFFF FFFF FFFF 2B2B 2BFF FF2B FFFF 2B2B 2B2B 2B2B 2BFF 2B2B"
	$"2BFF FF2B FFFF 2BFF FF2B FFFF 2BFF 2B2B 2BFF FF2B FFFF 2BFF 00FF"
	$"00FF 2BFF 2B2B 2BFF FF2B 2BFF 2BE3 E3E3 E3E3 2BFF 2B2B 2BFF FF2B"
	$"FFFF 2BFC FCFC FCFC FCFF FFFF 2BFF FF2B FFFF FFFF FFFF FFFF FFFF"
	$"00FF 2BFF FF2B FF00 0500 0000 0500 0000 05FF 2BFF FF2B FF00 EC00"
	$"0500 0000 0500 00FF 2BFF FF2B FFFF FFFF FFFF FFFF FFFF FFFF 2BFF"
	$"FF2B 2B2B 2B2B 2B2B 2B2B 2B2B 2B2B 2BFF FF2B 2B2B FFFF FFFF FFFF"
	$"FFFF 2B2B 2BFF FFFF FFFF FFFF 0000 0000 FFFF FFFF FFFF"
};
