/* ------------------------------------------------------------------------------
FILENAME
	Resources.h

DESCRIPTION
	This module contains the ImageWriter LQ resource constants that
	are common to both the New (QuickDraw GX) API resources (NewAPIResources.r) 
	and the Old (QuickDraw) API resources (OldAPIResources.r).
		
COPYRIGHT
	 Copyright Apple Computer, Inc. 1988-1996
	 All rights reserved. 

	12/20/93		dmh		Sync'd with the shipping 1.0b3 GX driver.
	 8/28/94		dmh		Sync'd with the shipping 1.0.1 GX driver.
	 6/14/96		cn			Updated to support Universal Interfaces 2.1.

-------------------------------------------------------------------------------- */

#ifndef __NEWLWRESOURCES__
#define __NEWLWRESOURCES__
	
// Include the public QuickDraw GX printing files 
// #include "GXPrinting.h"


/*********************************************************************************
 *        						CONSTANTS			 							 					*
 *********************************************************************************/

/************* Constants shared among the ImageWriter LQresource files *************/

#define	kDrvrCreatorType						'scLQ'							// Creator type of the driver 
#define	kDrvrFileType							'pdvr'							// QuickDraw GX drivers have this type 
#define	kDriverName								"ImageWriter LQ"				// Name of the driver (C string) 

#define	kNewPaperTypesID						gxPrintingDriverBaseID		// Starting resource ID of the new API paper types 
#define	kNumNewPaperTypes						6									// Number of new API paper type definitions 

#define	kOldPaperTypesID						(kNewPaperTypesID + kNumNewPaperTypes + 1)	// Starting resource ID of the new API paper types 
#define	kNumOldPaperTypes						6															// Number of new API paper type definitions 

#define	kFirstMsgJumpTableOffset			4									// Offset (bytes) into message code segment jump table of first jump table entry 
#define	kNewAPISegmentID						0									// Resource ID of code segment containing routines that override new API messages 
#define	kOldAPISegmentID						1									// Resource ID of code segment containing routines that override old API messages 

#define	kLookRsrcID								(-4096)							// Resource ID of the driver's 'look' resource 
#define	kPAPCommRsrcID							(-4096)							// Resource ID of the driver's PAP 'comm' resource 
#define	kSerialCommRsrcID						(-4095)							// Resource ID of the driver's Serial 'comm' resource 
#define	kPrinterShareCommRsrcID				(-4094)							// Resource ID of the driver's PrinterShare 'comm' resource 

#define	kPrintOptionsDlgRsrcID				(-8138)							// Resource ID of the Options dialog that's linked to the Print dialog 

#define	kDriverStatusID						gxPrintingDriverBaseID + 1	// Resource ID of Page Transmission 'stat' resource 
#define		kSendingPartOfPageStatIdx		1									// Sending part of a page 'stat' list entry 

#define	kNoAlertCoolID							0									// Resource ID of 'cool' alert that tells Printing Manager not to alert 

#define	kHwinRsrcID								(-8192)							//	Resource ID of 'hwin' help resource used by the driver
#define	kHfdrRsrcID								(-5696)							//	Resource ID of 'hfdr' help resource used by the driver
#define	kFinderHelpSTRID						(gxPrintingDriverBaseID + 1)	//	Resource ID of 'STR ' help resource used by the driver

#define	isManualFeed							true								// Useful mnemonic for dealing with manual feed jobs 

#define	kBufferSize								9100								//	Size (in bytes) of the packaging and I/O buffers to use

																							//	Job collection item indices
#define	kHeadMotionItemIndex					0									// Index into the job collection of the head motion collection item 
#define	kTraySettingsItemIndex				1									// Index into the job collection of the tray settings collection item 

																							//	Resource ID's of the various StartSendPage strings used by the Raster Imaging Engine
#define	kHighResUniDirID						gxPrintingDriverBaseID			// High resolution printing with unidirectional head movement 
#define	kHighResBiDirID						(gxPrintingDriverBaseID + 1)	// High resolution printing with bidirectional head movement 
#define	kLowResUniDirID						(gxPrintingDriverBaseID + 2)	// Low resolution printing with unidirectional head movement 
#define	kLowResBiDirID							(gxPrintingDriverBaseID + 3)	// Low resolution printing with biidirectional head movement 

																							//	Resource ID's related to the Sheetfeeder configuration dialog
#define	kSheetFeederDLOG						gxPrintingDriverBaseID			// Sheetfeeder configuration DLOG 
#define	kSheetFeederDITL						gxPrintingDriverBaseID			// Sheetfeeder configuration DITL 

#define	kTray1Menu								gxPrintingDriverBaseID			// Menu of paper types for tray #1 
#define	kTray2Menu								(gxPrintingDriverBaseID + 1)	// Menu of paper types for tray #2 
#define	kTray3Menu								(gxPrintingDriverBaseID + 2)	// Menu of paper types for tray #3 

#define	kTray1Control							gxPrintingDriverBaseID			// Control for paper types for tray #1 
#define	kTray2Control							(gxPrintingDriverBaseID + 1)	// Control for paper types for tray #2 
#define	kTray3Control							(gxPrintingDriverBaseID + 2)	// Control for paper types for tray #3 

#define	kOneTrayPICT							gxPrintingDriverBaseID			// PICT respresenting a one tray configuration 
#define	kTwoTrayPICT							(gxPrintingDriverBaseID + 1)	// PICT respresenting a two tray configuration 
#define	kThreeTrayPICT							(gxPrintingDriverBaseID + 2)	// PICT respresenting a three tray configuration 

																							//	Resource ID's related to the LQ Options dialog panel
#define	kLQOptionsDITL							(gxPrintingDriverBaseID + 1)	// LQ Options dialog panel DITL 
#define	kLQOptionsXdtl							(gxPrintingDriverBaseID + 1)	// LQ Options dialog panel 'xdtl' 
#define	kLQOptionsPanl							gxPrintingDriverBaseID			// LQ Options dialog panel 'panl' 

																							//	Resource ID's related to the LQ Driver's paper input trays
#define	kDefaultTrayRsrcID					(gxTrayCountDataID + 1)		// Default 'tray' resource for the LQ 
#define	kDefaultSheetFeederRsrcID			(gxTrayCountDataID + 0)		// Default 'tray' resource for the LQ with a sheet feeder attached

#define	kDefaultTrayNameID					gxPrintingDriverBaseID			// Default 'tryn' resource for the non-sheet feeder configuration
#define	kDefaultSheetFdrTray1NameID		(gxPrintingDriverBaseID + 1)	// Default 'tryn' resource for tray #1 of the sheet feeder configuration 
#define	kDefaultSheetFdrTray2NameID		(gxPrintingDriverBaseID + 2)	// Default 'tryn' resource for tray #2 of the sheet feeder configuration 
#define	kDefaultSheetFdrTray3NameID		(gxPrintingDriverBaseID + 3)	// Default 'tryn' resource for tray #3 of the sheet feeder configuration 

																							//	Identifiers for the various (native mode) national character sets available
#define	kAmerican								0									//	American character set
#define	kBritish									1									//	British character set
#define	kDanish									2									//	Danish character set
#define	kFrench									3									//	French character set
#define	kGerman									4									//	German character set
#define	kItalian									5									//	Italian character set
#define	kSwedish									6									//	Swedish character set
#define	kSpanish									7									//	Spanish character set

																							//	'STR#' resource ID's used to support job format modes
#define	kFormatModeFontsID					gxPrintingDriverBaseID			// List of "native" mode fonts supported
#define	kFormatModeStylesID					(gxPrintingDriverBaseID + 1)	//	List of "well" known styles that are supported
#define 	kQualityID								(gxPrintingDriverBaseID + 2)
#define	kBoldStyle								1									//	Index into kFormatModeStylesID 'STR#' of the bold style string
#define	kUnderlineStyle						2									//	Index into kFormatModeStylesID 'STR#' of the underline style string
#define 	kBestString								1
#define 	kRoughString							2
#define 	kHelpID									(gxPrintingDriverBaseID + 3)
#endif __NEWLWRESOURCES__
