/* ------------------------------------------------------------------------------
FILENAME
	LaserSCResources.h

DESCRIPTION
	This module contains the LaserWriter SC resource constants that
	are common to both the New (QuickDraw GX) API resources (NewAPIResources.r) 
	and the Old (QuickDraw) API resources (OldAPIResources.r).
		
COPYRIGHT
	 Copyright Apple Computer, Inc. 1988-1996
	 All rights reserved. 

MODIFICATION HISTORY
	 6/14/96 - cn  - Updated to support Universal Interfaces 2.1.
	
-------------------------------------------------------------------------------- */

#ifndef __NEWLWRESOURCES__
#define __NEWLWRESOURCES__
	
// Include the public QuickDraw GX printing files 
// #include <GXPrinting.h>


/*********************************************************************************
 *        						CONSTANTS			 							 					*
 *********************************************************************************/

/************* Constants shared among the LaserWriter SC resource files *************/

#define	kDrvrCreatorType				'scSC'							// Creator type of the driver 
#define	kDrvrFileType					'pdvr'							// QuickDraw GX drivers have this type 
#define	kDriverName						"LaserWriter SC"				// Name of the driver (C string) 

#define	kBadVersionDLOG				gxPrintingDriverBaseID		// "Driver too new" dialog.

#define	kNewPaperTypesID				gxPrintingDriverBaseID		// Starting resource ID of the new API paper types 
#define	kNumNewPaperTypes				5									// Number of new API paper type definitions 

#define	kOldPaperTypesID				(kNewPaperTypesID + kNumNewPaperTypes + 1)	// Starting resource ID of the new API paper types 
#define	kNumOldPaperTypes				5															// Number of new API paper type definitions 

#define	kFirstMsgJumpTableOffset	4									// Offset (bytes) into message code segment jump table of first jump table entry 
#define	kNewAPISegmentID				0									// Resource ID of code segment containing routines that override new API messages 
#define	kOldAPISegmentID				1									// Resource ID of code segment containing routines that override old API messages 

#define	kLookRsrcID						(-4096)							// Resource ID of the driver's 'look' resource 
#define	kSCSICommRsrcID				(-4095)							// Resource ID of the driver's SCSI 'comm' resource 
#define	kPrinterShareCommRsrcID		(-4094)							// Resource ID of the driver's PrinterShare 'comm' resource 

#define	kTransmissionStatID						gxPrintingDriverBaseID + 1	// Resource ID of Page Transmission 'stat' resource 
#define		kWaitingForPaperStatIdx				1						// Waiting for paper 'stat' list entry 
#define		kSendingPartOfPageStatIdx			2						// Sending part of a page 'stat' list entry 
#define		kPreparingPartOfPageStatIdx		3						// Preparing part of a page 'stat' list entry 
#define		kOutOfPaperStatIdx					4						// Out of paper 'stat' list entry 
#define		kPaperJamStatIdx						5						// Paper jam 'stat' list entry 
#define		kBadPaperCartridgeStatIdx			6						// Bad paper cartridge 'stat' list entry 
#define		kOpenDoorStatIdx						7						// Printer door open 'stat' list entry 
#define		kOpenDoorNoAlertStatIdx				8						// Printer door open 'stat' list entry 
#define		kPrintTestStatIdx						9						// Print test is in progress 'stat' list entry 
#define		kHeatFixingUnitStatIdx				10						// Fixing unit is being heated 'stat' list entry 
#define		kBadTonerCartridgeStatIdx			11						// Toner cartridge improperly loaded 'stat' list entry 
#define		kBadTonerCartridgeNoAlertStatIdx	12						// Toner cartridge improperly loaded 'stat' list entry 
#define		kPrintingPageStatIdx					13						// Printing the page 'stat' list entry 
#define		kCantFindPrinterStatIdx				14						// Can't locate the printer on the SCSI bus 'stat' list entry 
#define		kOpeningConnectionStatIdx			15						// Opening a connection to the printer 'stat' list entry 

#define	kEngineStatusStatID					gxPrintingDriverBaseID + 2	// Resource ID of Engine Failure 'stat' resource 
#define		kLaserInitFailureStatIdx		1							// Laser printer engine initialization failed 'stat' list entry 
#define		kDRamFailureStatIdx				2							// Dynamic RAM test failure 'stat' list entry 
#define		kBadPrintFixStatIdx				3							// Fixing assembly malfunctioned 'stat' list entry 
#define		kBadLaserStatIdx					4							// Laser has malfunctioned 'stat' list entry 
#define		kBadPolyMotorStatIdx				5							// Polygon motor has malfunctioned 'stat' list entry 
#define		kBadSerialStatIdx					6							// Serial communication malfunction 'stat' list entry 
#define		kGenericBadHdwareStatIdx		7							// Hardware malfunction 'stat' list entry 
#define		kDriverTooNewIdx					8							// "Driver too new" entry. 

#define	kNoAlertCoolID							0							// Resource ID of 'cool' alert that tells Printing Manager not to alert 
#define	kLaserInitFailureCoolID				gxPrintingDriverBaseID + 1	// Resource ID of Laser printer engine initialization failed 'cool' alert (all are relative to gxPrintingDriverBaseID) 
#define	kDRamFailureCoolID					gxPrintingDriverBaseID + 2	// Resource ID of Dynamic RAM test failure 'cool' alert 
#define	kBadPrintFixCoolID					gxPrintingDriverBaseID + 3	// Resource ID of Fixing assembly malfunctioned 'cool' alert 
#define	kBadLaserCoolID						gxPrintingDriverBaseID + 4	// Resource ID of Laser has malfunctioned 'cool' alert 
#define	kBadPolyMotorCoolID					gxPrintingDriverBaseID + 5	// Resource ID of Polygon motor has malfunctioned 'cool' alert 
#define	kBadSerialCoolID						gxPrintingDriverBaseID + 6	// Resource ID of Serial communication malfunction 'cool' alert 
#define	kGenericBadHdwareCoolID				gxPrintingDriverBaseID + 7	// Resource ID of Hardware malfunction 'cool' alert 
#define	kPrinterDoorOpenCoolID				gxPrintingDriverBaseID + 8	// Resource ID of Printer door open 'cool' alert 
#define	kBadTonerCartridgeCoolID			gxPrintingDriverBaseID + 9	// Resource ID of Bad toner cartridge 'cool' alert 
#define	kCantFindPrinterCoolID				gxPrintingDriverBaseID + 10	// Resource ID of Can't find printer 'cool' alert 
#define	kBadVersionAlertID					gxPrintingDriverBaseID + 11	// Resource ID of "Driver Too New" alert.

#define	kHwinRsrcID								(-8192)					//	Resource ID of 'hwin' help resource used by the driver
#define	kHfdrRsrcID								(-5696)					//	Resource ID of 'hfdr' help resource used by the driver
#define	kFinderHelpSTRID						(gxPrintingDriverBaseID + 1)	//	Resource ID of 'STR ' help resource used by the driver

#define	isManualFeed							true						// Useful mnemonic for dealing with manual feed jobs 


/************* Old Style Print Record Constants *************/

#define	kPrinterID						4		// The device ID (upper byte of wDev) for LaserWriter SC 

#define	kHorizHighRes					300	// high resolution horizontally (dpi) 
#define	kHorizHighExactRes			288	// high resolution horizontally (dpi) with exact bitmap scaling
#define	kVertHighRes					300	// high resolution vertically (dpi) 
#define	kVertHighExactRes				288	// high resolution vertically (dpi)  with exact bitmap scaling


/****************************************************************
* The imageable area defaults are in 72nds of an inch. 			*
* The LaserWriter IISC uses 10.6" x 8" 								*
* Compatibility Note: Currently, all page sizes are 				*
* calculated without fudge factors.  As a result, they do not	*
* exactly match the sizes in the old drivers.  They will			*
* eventually, and the current method will be used for all new	*
* page sizes and for all new drivers. 									*
****************************************************************/

#define	kRPageDefault					0, 0, 762, 576			// Default rPage (top,left,bottom,right) 
#define	kRPaperDefault					-15, -18, 777, 594	// Default rPaper 

/****************************************************************
* The high res page size for the device which has 4x scaling.	*
* Needed in the default print record, but doesn't enter into 	*
* any of the calculations at validation or StlDialog time		*
****************************************************************/

#define	kRPageHighExactRes			0, 0, 3168, 2304

/****************************************************************
* These fields are also for compatibility.  We don't need any	*
* of them for the new Print Architecture.  If you feel like		*
* it, you can try to define kPatScale to the be the pattern		*
* stretching you will be using.  However, the Imaging Engine	*
* doesn't look at it, since it doesn't need to.						*
****************************************************************/

#define	kPatScale						-4		// Pattern scaling factor (-4 means 4x, no bit thinning). 
														//	It's obsolete under the new printing architecture 
#define	kULThick							0		// Underline thickness factor. 
														//	It's obsolete under the new printing architecture 
#define	kULOffset						0		// Underline offset factor. 
														//	It's obsolete under the new printing architecture 
#define	kULShadow						0		// Underline shadow factor. 
														//	It's obsolete under the new printing architecture 
#define	kScanDirection					0		// How the page is printed (top to bottom). 
														//	It's obsolete under the new printing architecture 

#endif __NEWLWRESOURCES__
