#==============================================================================================
#
#	Make FILE:		LaserWriterIISC.make
#
#	VERSION:			1.0
#
#	COPYRIGHT:		(c) 1992-1996 Apple Computer Inc.
#						All rights reserved.
#
#	PURPOSE:			This file contains the build commands for the LaserWriterIISC driver.
#
#   6/14/96 - cn  - Updated to support MPW Pro #19.
#   8/28/94 - dmh - Finalized for SDK.
#  12/18/93 - dmh - Updated for the b3 seed.
#	9/13/93 - dmh - Updated for the b2 seed.
#	4/26/93 - dmh - Made makefile totally self-supporting for b1 seed.
#	4/26/93 - dh  - Made makefile totally self-supporting for f1 seed.
#
#==============================================================================================

#======= Point this variable to your GX libraries directory =======

GXLibrariesSources			=	{MPW}GXLibraries:
GXCompatibilityInterfaces	=	{MPW}GX Compatibility Interfaces:

#========== Directories Containing Source and Object Files ==========

Objects					=	:Objects:
Sources					=	

#========== Compiler Options ==========

AsmOptions				=	-case obj
RezOptions				=	-d SystemSevenOrLater=1 -i "{Rincludes}"
COptions				=	-d applec -b2 -i "{CIncludes}" -i "{GXLibrariesSources}" -i "{GXCompatibilityInterfaces}"
LinkOptions				=	-ra =resSysHeap,resPurgeable

#========== Printing Manager Dependent Header Files ==========

PrintManagerHeaderFiles	=	"{GXCompatibilityInterfaces}PrintingManager.h"		
							"{GXCompatibilityInterfaces}PrintingMessages.h"		
							"{GXCompatibilityInterfaces}PrintingExtensions.h"	
							"{CIncludes}Collections.h"							
							"{CIncludes}GXMessages.h"							
							"{GXCompatibilityInterfaces}PrintingResTypes.h"		
							"{GXCompatibilityInterfaces}PrintingErrors.h"

GraphicsHeaderFiles		=	"{GXCompatibilityInterfaces}graphics routines.h"	
							"{GXLibrariesSources}GraphicsLibraries.h"			
							"{GXCompatibilityInterfaces}math routines.h"			

#========== Files to Link into OldAPI Segment ==========

OldAPISegObjs	=	"{Objects}OldAPIMsgJumpTable.a.o"		
					"{Objects}OldAPIMessageIntf.c.o"			
					"{Libraries}MacRuntime.o"


#========== Files to Link into Universal Message Segment ==========

UnivSegObjs		=	"{Objects}UniversalMsgJumpTable.a.o"		
					"{Objects}LaserSCIntf.c.o"					
					"{Objects}SCPrinterStatus.c.o"				
					"{Objects}UniversalMessageIntf.c.o"			
					"{Objects}QDLibrary.c.o"					
					"{Objects}ColorLibrary.c.o"					
					"{CLibraries}StdCLib.o"						
					"{Libraries}"MacRuntime.o					
					"{Libraries}"Interface.o					


#========== Files to Link into the Chooser PACK ==========

ChooserPackObjs =	"{Objects}ChooserSupport.a.o"				
					"{Objects}ChooserSupport.c.o"				
					"{Libraries}"Interface.o					

#========== Files to Link into the Chooser LDEF ==========

ChooserLDEFObjs =	"{Objects}ChooserSupport.c.o"				
					"{Libraries}"Interface.o					

#========== Link and Rez Build Statements ==========

"LaserWriterIISC"				{OldAPISegObjs} 								
								{UnivSegObjs}									
								{ChooserPackObjs}								
								{ChooserLDEFObjs}								
								"{Sources}LaserWriterIISC.make"			
								"{Sources}LaserSCResources.r"				
								"{Sources}OldAPIResources.r"				
								"{Sources}UniversalMessageResources.r"		
		Link {UnivSegObjs}									
			  {LinkOptions}									
			  -rt pdvr=0										
			  -sg "LaserWriterIISC"							
			  -m SD_UniversalMsgJumpTable					
			  -o "{Objects}LWSC_UnivSeg" 
		Link {OldAPISegObjs}									
			  {LinkOptions}									
			  -rt pdvr=1										
			  -sg "LaserWriterIISC"							
			  -m SD_OldAPIMsgJumpTable						
			  -o "{Objects}LWSC_OldAPISeg" 
		Link	{ChooserPackObjs}								
				-rt PACK=-4096									
				-sg PrintingPACK								
				-m EntryPoint									
				-o "{Objects}LWSC_PACK"
		Link	{ChooserLDEFObjs}								
				-w													
				-rt LDEF=-4096									
				-sg LDEF											
				-m LDEF											
				-o "{Objects}LWSC_LDEF"
		Rez	{RezOptions} -c 'scSC' -t 'pdvr' -ov -s {Objects}					
				-o "LaserWriterIISC" "{Sources}LaserSCResources.r" "{Sources}OldAPIResources.r"	
				"{Sources}UniversalMessageResources.r" "{Sources}ChooserSupport.r" -append


#========== Assemble Build Statements - OldAPIMsgJumpTable.a ==========

"{Objects}OldAPIMsgJumpTable.a.o"	 	"{Sources}OldAPIMsgJumpTable.a"		
										"{Sources}LaserWriterIISC.make"
	Asm {AsmOptions} {MakeJumpTable} "{Sources}OldAPIMsgJumpTable.a" -o "{Objects}OldAPIMsgJumpTable.a.o"
	

#========== Assemble Build Statements - UniversalMsgJumpTable.a ==========

"{Objects}UniversalMsgJumpTable.a.o"	 	"{Sources}UniversalMsgJumpTable.a"		
											"{Sources}LaserWriterIISC.make"
	Asm {AsmOptions} {MakeJumpTable} "{Sources}UniversalMsgJumpTable.a" -o "{Objects}UniversalMsgJumpTable.a.o"
	

#========== Assemble Build Statements - ChooserSupport.a ==========

"{Objects}ChooserSupport.a.o"	 	"{Sources}ChooserSupport.a"		
									"{Sources}LaserWriterIISC.make"
	Asm {AsmOptions} {MakeJumpTable} "{Sources}ChooserSupport.a" -o "{Objects}ChooserSupport.a.o"
	

#========== Compile Build Statements - LaserSCIntf.c ==========

"{Objects}QDLibrary.c.o"		 "{GXLibrariesSources}QDLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}QDLibrary.c"

"{Objects}ColorLibrary.c.o"		 "{GXLibrariesSources}ColorLibrary.c"
	SC {COptions} -o {Objects} "{GXLibrariesSources}ColorLibrary.c"


"{Objects}LaserSCIntf.c.o"			"{Sources}LaserSCIntf.c"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}LaserWriterIISC.make"		
									"{Sources}LaserSCResources.h" 		
									"{Sources}LaserSCIntf.h"
	SC "{Sources}LaserSCIntf.c" -o "{Objects}LaserSCIntf.c.o"  {COptions}


#========== Compile Build Statements - OldAPIMessageIntf.c ==========

"{Objects}OldAPIMessageIntf.c.o"		"{Sources}OldAPIMessageIntf.c"	
										{PrintManagerHeaderFiles}			
										{GraphicsHeaderFiles}				
										"{Sources}LaserWriterIISC.make"	
										"{Sources}LaserSCResources.h" 	
										"{Sources}OldAPIMessageIntf.h"
	SC "{Sources}OldAPIMessageIntf.c" -o "{Objects}OldAPIMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - SCPrinterStatus.c ==========

"{Objects}SCPrinterStatus.c.o"		"{Sources}SCPrinterStatus.c"		
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}LaserWriterIISC.make"		
									"{Sources}LaserSCResources.h" 		
									"{Sources}LaserSCIntf.h"			
									"{Sources}SCPrinterStatus.h"
	SC "{Sources}SCPrinterStatus.c" -o "{Objects}SCPrinterStatus.c.o"  {COptions}


#========== Compile Build Statements - UniversalMessageIntf.c ==========

"{Objects}UniversalMessageIntf.c.o"		"{Sources}UniversalMessageIntf.c"		
										{PrintManagerHeaderFiles}				
										{GraphicsHeaderFiles}					
										"{Sources}LaserWriterIISC.make"			
										"{Sources}LaserSCResources.h" 			
										"{Sources}LaserSCIntf.h"				
										"{Sources}SCPrinterStatus.h"			
										"{Sources}UniversalMessageIntf.h"
	SC "{Sources}UniversalMessageIntf.c" -o "{Objects}UniversalMessageIntf.c.o"  {COptions}


#========== Compile Build Statements - ChooserSupport.c ==========

"{Objects}ChooserSupport.c.o"		"{Sources}ChooserSupport.c"			
									{PrintManagerHeaderFiles}			
									{GraphicsHeaderFiles}				
									"{Sources}LaserWriterIISC.make"		
									"{Sources}ChooserSupport.a" 		
									"{Sources}ChooserSupport.r" 			
	SC "{Sources}ChooserSupport.c" -o "{Objects}ChooserSupport.c.o"  {COptions}


