/* ------------------------------------------------------------------------------
FILENAME
	OldAPIMessageIntf.h

DESCRIPTION
	This module contains contants and types which are specifically used by the
	OldAPIMessageIntf.c file.  That file implements the LaserWriter SC's old
	API messages.
	
COPYRIGHT
	 Copyright Apple Computer, Inc. 1988-1992
	 All rights reserved. 
	
-------------------------------------------------------------------------------- */

#ifndef __OLDAPIMESSAGEINTF__
#define __OLDAPIMESSAGEINTF__


/*********************************************************************************
 *        									CONSTANTS												*
 *********************************************************************************/

// Miscellaneous constants
enum
{
	kMysticPaperFract				= 120,	// Paper sizes in PREC 3 are expressed as multiples of 120 
	kLetterRowBytes				= 300,	// Bitmap rowBytes for US Letter paper: 8" printing width 	
	kLegalRowBytes					= 252,	// Bitmap rowBytes for US Legal paper: 6.72" printing width	
	
	oldLWSCPrintRecordVersion	= 3,		//	This is the print record version supported by the last non-QuickDraw GX based LaserWriter SC driver

	oldPRECAutoFeed				= 1,		//	Old SC driver auto-feed setting constant
	oldPRECManualFeed				= 0		//	Old SC driver manual feed setting constant
};

// Useful bit numbers in the print record 
enum
{
	kTextSmoothingBit		= (1 << 0),	// bit0
	kScale75Bit				= (1 << 2),	// bit2
	kScale50Bit				= (1 << 3),	//	bit3
	kExactBitBit			= (1 << 4),	//	bit4
	kDevResBit				= (1 << 5),	//	bit5
	kDraftBitsBit			= (1 << 6),	//	bit6
	kScale25Bit				= (1 << 7),	//	bit7
	kAbortChkBit			= (1 << 8),	//	bit8
	kGrayScaleBit			= (1 << 9),	//	bit9

	kPortraitBit			= (1 << 1)	//	bit1, in wDev - rest are in iFlags 
};

	
/*********************************************************************************
 *        									DEFINES													*
 *********************************************************************************/

// TestBit - for testing a masked bit 

#define TestBit(i, bit)		(((i) & (bit)) == (bit))


/*********************************************************************************
 *        							FORWARD DECLARATIONS											*
 *********************************************************************************/

OSErr	SD_PrValidate(THPrint hPrint, Boolean *wasChanged);
OSErr SD_ConvertPrintRecordTo(THPrint hPrint);
OSErr SD_ConvertPrintRecordFrom(THPrint hPrint);

#endif __OLDAPIMESSAGEINTF__