/*---------------------------------------------------------------------------
FILENAME
	SCPrinterStatus.h

DESCRIPTION
	This module contains the constant and type declarations for the 
	SCPrinterStatus.c file.  That file contains the routines which manage
	checking the status of the SC printer and alerting the user (as needed) to
	problems that might arise.
	
	Note: this file contains some types and constants that need to be moved
	from the Universal Driver to the public printing interfaces.
		
COPYRIGHT
	Copyright Apple Computer, Inc. 1989-1996
	All rights reserved. 

MODIFICATION HISTORY
	 6/14/96 - cn  - Updated to support Universal Interfaces 2.1.
-------------------------------------------------------------------------- */

#ifndef __SCPRINTERSTATUS__
#define __SCPRINTERSTATUS__
	

/*********************************************************************************
 *        								 CONSTANTS		 											*
 *********************************************************************************/

// Miscellaneous constants 
enum
{
	kNoPrinterProblem		= 0,			// Indicates printer is not experiencing any problems 
	kQueryRate				= 15			// Number of ticks between status commands to the printer
};


/*********************************************************************************
 *        									DEFINES													*
 *********************************************************************************/

#define	GetStatResID(printerProblem)			HiWord(printerProblem)
#define	GetStatResIndex(printerProblem)		LoWord(printerProblem)


/*********************************************************************************
 *        							FORWARD DECLARATIONS											*
**********************************************************************************/

void SetPrinterProblemStatResIndex(short statResIndex, long *printerProblem);

void SetPrinterProblemStatResID(short statResID, long *printerProblem);

OSErr FindPrinterProblem(long *printerProblem,  Boolean *fAbort);

OSErr ResolvePrinterProblem(	long	 		printerProblem, 
										Boolean 		manualFeed,
										gxPaperType	thePaperType,
										short			*dialogResult);

#endif __SCPRINTERSTATUS__